/****************************************************************************
 ** Modern Linbo GUI
 ** Copyright (C) 2020  Dorian Zedler <dorian@itsblue.de>
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU Affero General Public License as published
 ** by the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU Affero General Public License for more details.
 **
 ** You should have received a copy of the GNU Affero General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/

#include "../headers/linbogui.h"

LinboGui::LinboGui()
{
    // fill whole screen
    Qt::WindowFlags flags;
    flags = Qt::FramelessWindowHint | Qt::WindowStaysOnBottomHint;
    setWindowFlags( flags );
    setAttribute( Qt::WA_AlwaysShowToolTips );
    this->setGeometry(QApplication::desktop()->screenGeometry());
    this->setFixedHeight(QApplication::desktop()->screenGeometry().height());
    this->setFixedWidth(QApplication::desktop()->screenGeometry().width());

    QFontDatabase db;
    qDebug() << QFontDatabase::addApplicationFont(":/fonts/SegoeUI.ttf");
    qDebug() << db.families();

    // white bakground
    // linuxmuster background color: #394f5e
    this->setStyleSheet( "QDialog { background: white }");

    // create the backend
    this->backend = new LinboBackend(this);

    // create start page
    this->startPage = new LinboStartPage(this->backend, this);

}

// prevent closing (eg. by pressing escape key)
void LinboGui::done(int r) {
    Q_UNUSED(r)
}
